@@ -5,7 +5,6 @@
  */
 
 #include "mainwindow.h"
-#include "translate.h"
 #include "ui_mainwindow.h"
 
 #include "easyviewwidget.h"
@@ -17,8 +16,6 @@
 #include "configtreetext.h"
 #include "custom.h"
 
-#include <iostream>
-#include <iomanip>
 #include <QDropEvent>
 #include <QFileDialog>
 #include <QMessageBox>
@@ -34,6 +31,10 @@
 #include <QToolBar>
 #include <QMainWindow>
 #include <QMenuBar>
+#include <QTranslator>
+#include <QFontDatabase>
+#include <QPushButton>
+#include <QDesktopServices>
 /*
 #include <qwt/qwt_plot.h>
 #include <qwt/qwt_plot_curve.h>
@@ -48,7 +49,12 @@ using namespace ZenLib;
 #define QString2wstring(_DATA) \
     Ztring().From_UTF8(_DATA.toUtf8())
 
-#define VERSION "21.09"
+#define VERSION "25.07"
+
+#ifndef MEDIAINFO_HTML_NO
+#include "htmlwidget.h"
+#endif
+
 #if defined(_WIN32) && defined(WINAPI_FAMILY) && (WINAPI_FAMILY==WINAPI_FAMILY_APP) //UWP Application
 #include <QtPlatformHeaders/QWindowsWindowFunctions>
 #include <ZenLib/Os_Utils.h>
@@ -170,7 +176,8 @@ MainWindow::MainWindow(QStringList filesnames, int viewasked, QWidget *parent) :
     setWindowTitle("MediaInfo");
 #endif
 
-    settings = new QSettings("MediaArea.net", "MediaInfo");
+    translator = new QTranslator(this);
+    settings = new QSettings("MediaArea.net", "MediaInfo", this);
     defaultSettings();
     applySettings();
 
@@ -187,31 +194,41 @@ MainWindow::MainWindow(QStringList filesnames, int viewasked, QWidget *parent) :
 #endif
 
     //tests
+#if QT_VERSION > QT_VERSION_CHECK(6, 7, 0)
+    ui->actionQuit->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::WindowClose));
+    ui->actionClose_All->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::WindowClose));
+#else
     ui->actionQuit->setIcon(style()->standardIcon(QStyle::SP_DialogCloseButton));
     ui->actionClose_All->setIcon(style()->standardIcon(QStyle::SP_DialogCloseButton));
+#endif
     ui->actionOpen->setIcon(QIcon(":/icon/openfile.svg"));
     ui->actionOpen_Folder->setIcon(QIcon(":/icon/opendir.svg"));
     ui->actionAbout->setIcon(QIcon(":/icon/about.svg"));
     ui->actionExport->setIcon(QIcon(":/icon/export.svg"));
 
-    menuView = new QMenu();
-   QActionGroup* menuItemGroup = new QActionGroup(this);
-   for(int v=VIEW_EASY;v<NB_VIEW;v++) {
-       QAction* action = new QAction(nameView((ViewMode)v), menuItemGroup);
-       action->setCheckable(true);
-       if(view==v)
-           action->setChecked(true);
-       action->setProperty("view",v);
-       ui->menuView->addAction(action);
-       menuView->addAction(action);
-   }
-   connect(menuItemGroup,SIGNAL(triggered(QAction*)),this,SLOT(actionView_toggled(QAction*)));
+    menuView = new QMenu(this);
+    QActionGroup* menuItemGroup = new QActionGroup(this);
+    for(int v=VIEW_EASY;v<NB_VIEW;v++) {
+        QAction* action = new QAction(nameView((ViewMode)v), menuItemGroup);
+        action->setCheckable(true);
+        #if defined(MEDIAINFO_HTML_NO)
+        if (v==VIEW_HTML || v==VIEW_GRAPH)
+            action->setEnabled(false);
+        #endif
 
-   buttonView = new QToolButton();
-   buttonView->setText("view");
-   buttonView->setIcon(QIcon(":/icon/view.svg"));
-   connect(buttonView, SIGNAL(clicked()), this, SLOT(buttonViewClicked()));
-   ui->toolBar->addWidget(buttonView);
+        if(view==v)
+            action->setChecked(true);
+        action->setProperty("view",v);
+        ui->menuView->addAction(action);
+        menuView->addAction(action);
+    }
+    connect(menuItemGroup,SIGNAL(triggered(QAction*)),this,SLOT(actionView_toggled(QAction*)));
+
+    buttonView = new QToolButton();
+    buttonView->setText("view");
+    buttonView->setIcon(QIcon(":/icon/view.svg"));
+    connect(buttonView, SIGNAL(clicked()), this, SLOT(buttonViewClicked()));
+    ui->toolBar->addWidget(buttonView);
 
     ui->toolBar->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(ui->toolBar,SIGNAL(customContextMenuRequested(QPoint)),this,SLOT(toolBarOptions(QPoint)));
@@ -244,6 +261,7 @@ MainWindow::MainWindow(QStringList filesnames, int viewasked, QWidget *parent) :
 
 MainWindow::~MainWindow()
 {
+    delete C;
     delete ui;
 }
 
@@ -270,33 +288,33 @@ void MainWindow::checkForNewVersion() {
     reply = qnam.get(QNetworkRequest(url));
     qDebug() << "downloading " << url.toString();
 
-     connect(reply, SIGNAL(finished()), this, SLOT(httpFinished()));
-     connect(reply, SIGNAL(readyRead()), this, SLOT(httpReadyRead()));
+    connect(reply, SIGNAL(finished()), this, SLOT(httpFinished()));
+    connect(reply, SIGNAL(readyRead()), this, SLOT(httpReadyRead()));
 
 }
 
 void MainWindow::httpFinished()
 {
-         if (reply->error()) {
-             qDebug() << "Download failed";
-         } else {
-             qDebug() << "Downloaded file to temp string.";
-         }
+    if (reply->error()) {
+        qDebug() << "Download failed";
+    } else {
+        qDebug() << "Downloaded file to temp string.";
+    }
 
-         ZtringListList X;
-         X.Write(file.toStdString().c_str());
-         if (isNewer(wstring2QString(X("NewVersion")),QString(VERSION))) {
-             qDebug() << "New version is available.";
-             qDebug() << "latest is " << wstring2QString(X("NewVersion")).toStdString().c_str();
-             ui->menuBar->addAction(Tr("Update to new version"),this,SLOT(updateToNewVersion()));
-         } else {
-             qDebug() << "No new version available.";
-             qDebug() << "latest is " << wstring2QString(X("NewVersion")).toStdString().c_str();
-         }
+    ZtringListList X;
+    X.Write(file.toStdString().c_str());
+    if (isNewer(wstring2QString(X("NewVersion")),QString(VERSION))) {
+        qDebug() << "New version is available.";
+        qDebug() << "latest is " << wstring2QString(X("NewVersion")).toStdString().c_str();
+        ui->menuBar->addAction(tr("Update to new version"),this,SLOT(updateToNewVersion()));
+    } else {
+        qDebug() << "No new version available.";
+        qDebug() << "latest is " << wstring2QString(X("NewVersion")).toStdString().c_str();
+    }
 
-         reply->deleteLater();
-         reply = 0;
-         file = "";
+    reply->deleteLater();
+    reply = 0;
+    file = "";
 }
 
 void MainWindow::updateToNewVersion() {
@@ -305,7 +323,7 @@ void MainWindow::updateToNewVersion() {
 
 void MainWindow::httpReadyRead()
 {
-        file.append(reply->readAll());
+    file.append(reply->readAll());
 }
 #endif //NEW_VERSION
 
@@ -316,26 +334,26 @@ void MainWindow::toolBarOptions(QPoint p) {
     return;
 #else
     QMenu menu("toolbar options",ui->toolBar);
-    QMenu *menuI = new QMenu(Tr("Icon size"));
-    QMenu *menuT = new QMenu(Tr("Text position"));
+    QMenu *menuI = new QMenu(tr("Icon size"));
+    QMenu *menuT = new QMenu(tr("Text position"));
 
     menu.addMenu(menuT);
-    QString textsT[NBNAMES] = {Tr("Icons only"),Tr("Text only"),Tr("Text under icons"),Tr("Text beside icons")};
+    QString textsT[NBNAMES] = {tr("Icons only"),tr("Text only"),tr("Text under icons"),tr("Text beside icons")};
     QAction* actionsT[NBNAMES+1];
     Qt::ToolButtonStyle styles[NBNAMES] = {Qt::ToolButtonIconOnly,Qt::ToolButtonTextOnly,Qt::ToolButtonTextUnderIcon,Qt::ToolButtonTextBesideIcon};
     for(int i=0;i<NBNAMES;i++) {
         actionsT[i] = menuT->addAction(textsT[i]);
     }
-    actionsT[NBNAMES] = menuT->addAction(Tr("Default"));
+    actionsT[NBNAMES] = menuT->addAction(tr("Default"));
 
     menu.addMenu(menuI);
-    QString textsI[NBSIZES] = {Tr("Small"),Tr("Medium"),Tr("Big"),Tr("Huge")};
+    QString textsI[NBSIZES] = {tr("Small"),tr("Medium"),tr("Big"),tr("Huge")};
     QAction* actionsI[NBNAMES+1];
     QSize sizes[NBSIZES+1] = {QSize(16,16),QSize(22,22),QSize(32,32),QSize(48,48)};
     for(int i=0;i<NBSIZES;i++) {
         actionsI[i] = menuI->addAction(textsI[i]+"("+QString::number(sizes[i].width())+"x"+QString::number(sizes[i].height())+")");
     }
-    actionsI[NBSIZES] = menuI->addAction(Tr("Default"));
+    actionsI[NBSIZES] = menuI->addAction(tr("Default"));
 
     QAction* a = menu.exec(ui->toolBar->mapToGlobal(p));
     if(a) {
@@ -404,9 +422,28 @@ QDir MainWindow::getCommonDir(Core*C) {
 void MainWindow::changeEvent(QEvent *e)
 {
     QMainWindow::changeEvent(e);
+    QFile file;
     switch (e->type()) {
     case QEvent::LanguageChange:
         ui->retranslateUi(this);
+        // force refresh of text of view button on toolbar
+        buttonView->setText(tr("View"));
+        ui->toolBar->setToolButtonStyle(Qt::ToolButtonStyle(Qt::ToolButtonIconOnly));
+        ui->toolBar->setToolButtonStyle(Qt::ToolButtonStyle(settings->value("iconStyle",Qt::ToolButtonIconOnly).toInt()));
+        // update texts of view menu items
+        for(int v=VIEW_EASY;v<NB_VIEW;v++) {
+            ui->menuView->actions().at(v)->setText(nameView((ViewMode)v));
+        }
+        // set MediaInfoLib language
+        file.setFileName(":/languages/Plugin/Language/" + settings->value("language", "en").toString() + ".csv");
+        if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+            QTextStream in(&file);
+            QString fileContent = in.readAll();
+            C->MI->Option_Static(__T("Language"), fileContent.toStdWString());
+            file.close();
+        }
+        // refresh titlebar and MediaInfoLib output
+        refreshDisplay();
         break;
     default:
         break;
@@ -424,10 +461,24 @@ void MainWindow::openFiles(QStringList fileNames) {
     //Configuring
     if(fileNames.isEmpty())
         return;
-    for(int i=0;i<fileNames.size();i++) {
+    // Process input paths/filenames/URLs
+    for (int i = 0; i < fileNames.size(); ++i) {
+        // Skip processing if is a network URL
+        QUrl url(fileNames[i]);
+        if (url.isValid())
+            if (!url.scheme().isEmpty())
+                if (url.scheme().startsWith("http", Qt::CaseInsensitive) ||
+                    url.scheme().startsWith("ftp", Qt::CaseInsensitive) ||
+                    url.scheme().startsWith("sftp", Qt::CaseInsensitive))
+                    continue;
+        // Resolve to target if is a Windows .lnk shortcut
+        QFileInfo fileInfo(fileNames[i]);
+        if (fileInfo.suffix().compare("lnk", Qt::CaseInsensitive) == 0 && !fileInfo.symLinkTarget().isEmpty())
+            fileNames[i] = fileInfo.symLinkTarget();
+        // Convert directory separators to native separators for file paths
         fileNames[i] = QDir::toNativeSeparators(fileNames[i]);
     }
-    C->Menu_File_Open_Files_Begin(settings->value("closeBeforeOpen",true).toBool(), false);
+    C->Menu_File_Open_Files_Begin(settings->value("closeBeforeOpen",true).toBool(), true);
     for (int Pos=0; Pos<fileNames.size(); Pos++)
         C->Menu_File_Open_Files_Continue(QString2wstring(fileNames[Pos]));
     openTimerInit();
@@ -437,14 +488,14 @@ void MainWindow::openFiles(QStringList fileNames) {
 
 void MainWindow::openTimerInit ()
 {
-    progressDialog=new QProgressDialog(Tr("Opening files..."), Tr("Abort Opening"), 0, 10000, this);
+    progressDialog=new QProgressDialog(tr("Opening files..."), tr("Abort Opening"), 0, 10000, this);
     progressDialog->setWindowModality(Qt::WindowModal);
     progressDialog->setMinimumDuration(0);
     progressDialog->setWindowTitle("MediaInfo");
 
     if (timer==NULL)
     {
-        timer=new QTimer();
+        timer=new QTimer(this);
         connect(timer, SIGNAL(timeout()), this, SLOT(updateProgressBar()));
         timer->start(100);
     }
@@ -477,7 +528,7 @@ void MainWindow::openDir(QString dirName) {
 
     //Configuring
     dirName = QDir::toNativeSeparators(dirName);
-    C->Menu_File_Open_Files_Begin(settings->value("closeBeforeOpen",true).toBool(), false);
+    C->Menu_File_Open_Files_Begin(settings->value("closeBeforeOpen",true).toBool(), true);
     C->Menu_File_Open_Directory(QString2wstring(dirName));
     openTimerInit();
 
@@ -485,7 +536,13 @@ void MainWindow::openDir(QString dirName) {
 }
 
 void MainWindow::refreshDisplay() {
-    QFont font("Mono");
+    QFont font;
+    if (!settings->value("monoFont", "").toString().isEmpty()) {
+        font.fromString(settings->value("monoFont", "").toString());
+        font.setFamilies(QStringList({ font.family(), "Cascadia Mono", "Courier New", "Malgun Gothic", "MS Gothic", "NSimSun", "Mono" }));
+    } else {
+        font.setFamilies(QStringList({ "Cascadia Mono", "Courier New", "Malgun Gothic", "MS Gothic", "NSimSun", "Mono" }));
+    }
     font.setStyleHint(QFont::TypeWriter);
 
     ui->actionAdapt_columns_to_content->setVisible(false);
@@ -493,14 +550,28 @@ void MainWindow::refreshDisplay() {
     QWidget* viewWidget;
     ui->actionExport->setEnabled(C->Count_Get()>0);
     ui->actionClose_All->setEnabled(C->Count_Get()>0);
-    QDomDocument* xis;
+    QDomDocument* xis{nullptr};
+
+    C->Menu_Option_Preferences_Option(__T("Enable_Ffmpeg"), settings->value("enableFFmpeg",false).toBool() ? __T("1") : __T("0"));
+
+    switch(settings->value("displayCaptions",1).toInt()) {
+    case 0:
+        C->Menu_Option_Preferences_Option(__T("File_DisplayCaptions"),__T("Content"));
+        break;
+    case 1:
+        C->Menu_Option_Preferences_Option(__T("File_DisplayCaptions"),__T("Command"));
+        break;
+    case 2:
+        C->Menu_Option_Preferences_Option(__T("File_DisplayCaptions"),__T("Stream"));
+        break;
+    }
 
     if(C->Count_Get()<=0) {
 #if defined(_WIN32) && defined(WINAPI_FAMILY) && WINAPI_FAMILY==WINAPI_FAMILY_APP //UWP Application
-        viewWidget = new QLabel(Tr("You must at least open 1 file.\nOpen a file or a directory."));
+        viewWidget = new QLabel(tr("You must at least open 1 file.\nOpen a file or a directory."));
 #else
-        viewWidget = new QLabel(Tr("You must at least open 1 file.\nOpen a file or a directory, or simply drag n drop files in the window."));
-        setWindowTitle(Tr("MediaInfo"));
+        viewWidget = new QLabel(tr("You must at least open 1 file.\nOpen a file or a directory, or simply drag n drop files in the window."));
+        setWindowTitle(tr("MediaInfo"));
 #endif
         ((QLabel*)viewWidget)->setAlignment(Qt::AlignCenter);
     }
@@ -510,6 +581,8 @@ void MainWindow::refreshDisplay() {
             default:
             case VIEW_TEXT:
                 C->Menu_View_Text();
+                C->Menu_Option_Preferences_Option(__T("Inform_Version"), settings->value("informVersion",false).toBool() ? __T("1") : __T("0"));
+                C->Menu_Option_Preferences_Option(__T("Inform_Timestamp"), settings->value("informTimestamp",false).toBool() ? __T("1") : __T("0"));
                 viewWidget = new QTextBrowser();
                 ((QTextBrowser*)viewWidget)->setFont(font);
                 if(ConfigTreeText::getIndex()==0)
@@ -613,13 +686,30 @@ void MainWindow::refreshDisplay() {
                 xis->setContent(wstring2QString(C->Inform_Get()));
                 ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
                 break;
-            case VIEW_MPEG7:
-                C->Menu_View_MPEG7();
+            case VIEW_MPEG7_Strict:
+                C->Menu_View_MPEG7_Strict();
                 viewWidget = new QTextBrowser();
                 xis = new QDomDocument();
                 xis->setContent(wstring2QString(C->Inform_Get()));
                 ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
                 break;
+
+            case VIEW_MPEG7_Relaxed:
+                C->Menu_View_MPEG7_Relaxed();
+                viewWidget = new QTextBrowser();
+                xis = new QDomDocument();
+                xis->setContent(wstring2QString(C->Inform_Get()));
+                ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
+                break;
+
+            case VIEW_MPEG7_Extended:
+                C->Menu_View_MPEG7_Extended();
+                viewWidget = new QTextBrowser();
+                xis = new QDomDocument();
+                xis->setContent(wstring2QString(C->Inform_Get()));
+                ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
+                break;
+
             case VIEW_XML:
                 C->Menu_View_XML();
                 viewWidget = new QTextBrowser();
@@ -637,9 +727,16 @@ void MainWindow::refreshDisplay() {
                 viewWidget = new EasyViewWidget(C);
                 break;
             case VIEW_HTML:
-                C->Menu_View_HTML();
-                viewWidget = new QTextBrowser();
-                ((QTextBrowser*)viewWidget)->setHtml(wstring2QString(C->Inform_Get()));
+                #ifndef MEDIAINFO_HTML_NO
+                    C->Menu_View_HTML();
+                    viewWidget = new HTMLViewWidget(C, settings);
+                #endif
+                break;
+            case VIEW_GRAPH:
+                #ifndef MEDIAINFO_HTML_NO
+                    C->Menu_View_Graph_Svg();
+                    viewWidget = new HTMLViewWidget(C, settings);
+                #endif
                 break;
             case VIEW_TREE:
                 C->Menu_View_Tree();
@@ -647,7 +744,7 @@ void MainWindow::refreshDisplay() {
                 break;
             case VIEW_SHEET:
                 C->Menu_View_Sheet();
-                viewWidget = new SheetView(C,this);
+                viewWidget = new SheetView(C,this,&font);
                 ui->actionReset_field_sizes->setVisible(true);
                 if(!Sheet::getSheet()->getAdaptColumns())
                     ui->actionAdapt_columns_to_content->setVisible(true);
@@ -664,18 +761,48 @@ void MainWindow::refreshDisplay() {
         if(C->Count_Get()==1)
             setWindowTitle("MediaInfo - "+shortName(C,wstring2QString(C->Get(0, Stream_General, 0, __T("CompleteName")))));
         else
-            setWindowTitle(QString("MediaInfo - %1 ").arg((int)C->Count_Get())+Tr("files","window title"));
+            setWindowTitle(QString("MediaInfo - %1 ").arg((int)C->Count_Get())+tr("files","window title"));
 #endif
     }
-    setCentralWidget(viewWidget);
+
+    // Check if conformance glossary button should show
+    bool showGlossaryButton = false;
+    if (C->Count_Get() > 0) {
+        size_t FilePos = 0;
+        size_t AudioCount = C->Count_Get(FilePos, Stream_Audio, -1);
+        for (size_t AudioPos = 0; AudioPos < AudioCount; ++AudioPos) {
+            if (C->Get(FilePos, Stream_Audio, AudioPos, __T("ConformanceErrors")) != __T("") ||
+                C->Get(FilePos, Stream_Audio, AudioPos, __T("ConformanceWarnings")) != __T("")) {
+                showGlossaryButton = true;
+                break;
+            }
+        }
+    }
+    if (showGlossaryButton) {
+        // Show conformance glossary button below viewWidget
+        QWidget* compositeViewWidget = new QWidget(this);
+        QVBoxLayout* vLayout = new QVBoxLayout(compositeViewWidget);
+        QPushButton* footerButton = new QPushButton(tr("Go to conformance errors and warnings glossary page"));
+        connect(footerButton, SIGNAL(clicked()), this, SLOT(footerButtonClicked()));
+        vLayout->addWidget(viewWidget);
+        vLayout->addWidget(footerButton);
+        compositeViewWidget->setLayout(vLayout);
+        setCentralWidget(compositeViewWidget);
+    }
+    else
+        // Show just the viewWidget
+        setCentralWidget(viewWidget);
+
+    //Delete object(s)
+    if (xis) delete xis;
 }
 
 QTreeWidget* MainWindow::showTreeView(bool completeDisplay) {
     QTreeWidget* treeWidget = new QTreeWidget();
     //treeWidget->setHeaderHidden(true);
     treeWidget->setColumnCount(2);
-    QStringList headers = QStringList(Tr("key"));
-    headers.append(Tr("value"));
+    QStringList headers = QStringList(tr("key"));
+    headers.append(tr("value"));
     treeWidget->setHeaderLabels(headers);
     unsigned fileCount = (unsigned)C->Count_Get();
     QDir dir = getCommonDir(C);
@@ -759,7 +886,7 @@ QTreeWidget* MainWindow::showTreeView(bool completeDisplay) {
                             B=B.mid(level);
 
                         if (level==tree.count() && tree.back()->childCount())
-                           tree.append(tree.back()->child(tree.back()->childCount()-1));
+                            tree.append(tree.back()->child(tree.back()->childCount()-1));
                         else if (level<tree.count()-1)
                             tree.resize(level+1);
 
@@ -777,6 +904,11 @@ QTreeWidget* MainWindow::showTreeView(bool completeDisplay) {
         treeWidget->topLevelItem(0)->setExpanded(true);
     }
     treeWidget->resizeColumnToContents(0);
+    treeWidget->resizeColumnToContents(1);
+
+    connect(treeWidget, &QTreeWidget::expanded, [treeWidget]() { treeWidget->resizeColumnToContents(0); treeWidget->resizeColumnToContents(1); });
+    connect(treeWidget, &QTreeWidget::collapsed, [treeWidget]() { treeWidget->resizeColumnToContents(0); treeWidget->resizeColumnToContents(1); });
+
     return treeWidget;
 }
 
@@ -840,14 +972,14 @@ void MainWindow::defaultSettings() {
     if(Sheet::getNbSheets()==0) {
         Sheet::add("example");
         Sheet::setDefault(0);
-        Sheet::getSheet()->addColumn(Tr("File Name").toStdString().c_str(),300,Stream_General,"CompleteName");
-        Sheet::getSheet()->addColumn(Tr("Format").toStdString().c_str(),100,Stream_General,"Format");
-        Sheet::getSheet()->addColumn(Tr("Video Codec List").toStdString().c_str(),100,Stream_General,"Video_Codec_List");
-        Sheet::getSheet()->addColumn(Tr("Audio Codec List").toStdString().c_str(),100,Stream_General,"Audio_Codec_List");
-        Sheet::getSheet()->addColumn(Tr("Text Codec List").toStdString().c_str(),100,Stream_General,"Text_Codec_List");
-        Sheet::getSheet()->addColumn(Tr("Video Format").toStdString().c_str(),100,Stream_Video,"Format");
-        Sheet::getSheet()->addColumn(Tr("Audio Duration").toStdString().c_str(),100,Stream_Audio,"Duration");
-        Sheet::getSheet()->addColumn(Tr("Text Width").toStdString().c_str(),100,Stream_Text,"Width");
+        Sheet::getSheet()->addColumn(tr("File Name").toStdString().c_str(),300,Stream_General,"CompleteName");
+        Sheet::getSheet()->addColumn(tr("Format").toStdString().c_str(),100,Stream_General,"Format");
+        Sheet::getSheet()->addColumn(tr("Video Codec List").toStdString().c_str(),100,Stream_General,"Video_Codec_List");
+        Sheet::getSheet()->addColumn(tr("Audio Codec List").toStdString().c_str(),100,Stream_General,"Audio_Codec_List");
+        Sheet::getSheet()->addColumn(tr("Text Codec List").toStdString().c_str(),100,Stream_General,"Text_Codec_List");
+        Sheet::getSheet()->addColumn(tr("Video Format").toStdString().c_str(),100,Stream_Video,"Format");
+        Sheet::getSheet()->addColumn(tr("Audio Duration").toStdString().c_str(),100,Stream_Audio,"Duration");
+        Sheet::getSheet()->addColumn(tr("Text Width").toStdString().c_str(),100,Stream_Text,"Width");
     }
     ConfigTreeText::load(settings);
     if(ConfigTreeText::getNbConfigTreeTexts()==0) {
@@ -871,6 +1003,12 @@ void MainWindow::applySettings() {
     ui->toolBar->setVisible(settings->value("showToolbar",true).toBool());
     ui->toolBar->setToolButtonStyle(Qt::ToolButtonStyle(settings->value("iconStyle",Qt::ToolButtonIconOnly).toInt()));
     ui->toolBar->setIconSize(settings->value("iconSize",QSize(32,32)).toSize());
+    C->Menu_Option_Preferences_Option(__T("LegacyStreamDisplay"), settings->value("legacyStreamDisplay",false).toBool() ? __T("1") : __T("0"));
+    C->Menu_Option_Preferences_Option(__T("Cover_Data"), settings->value("coverData",false).toBool() ? __T("base64") : __T(""));
+
+    qApp->removeTranslator(translator);
+    Q_UNUSED(translator->load(settings->value("language", "en").toString(), ":/languages/Translations"));
+    qApp->installTranslator(translator);
 }
 
 void MainWindow::dropEvent(QDropEvent *event)
@@ -940,7 +1078,7 @@ void MainWindow::on_actionOpen_triggered()
         fileNames += Path;
     }
 #else
-    fileNames = QFileDialog::getOpenFileNames(this, Tr("Open File(s)"), getCommonDir(C).absolutePath());
+    fileNames = QFileDialog::getOpenFileNames(this, tr("Open File(s)"), getCommonDir(C).absolutePath());
 #endif
     openFiles(fileNames);
 
@@ -987,16 +1125,16 @@ void MainWindow::on_actionOpen_Folder_triggered()
 
     dirName = Path;
 #else
-    dirName = QFileDialog::getExistingDirectory(this,Tr("Open Folder"), getCommonDir(C).absolutePath());
+    dirName = QFileDialog::getExistingDirectory(this,tr("Open Folder"), getCommonDir(C).absolutePath());
 #endif
     openDir(dirName);
 
-   refreshDisplay();
+    refreshDisplay();
 }
 
 void MainWindow::on_actionAbout_triggered()
 {
-    About a(VERSION, this);
+    About a(this);
     a.exec();
 }
 
@@ -1041,6 +1179,7 @@ void MainWindow::on_actionPreferences_triggered()
         applySettings();
         if(settings->value("defaultView",VIEW_EASY)!=oldView) {
             this->view = (ViewMode)settings->value("defaultView",VIEW_EASY).toInt();
+            refreshDisplay();
         }
     }
 }
@@ -1087,6 +1226,10 @@ void MainWindow::on_actionExport_triggered()
             C->Menu_View_HTML();
             file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
             break;
+        case Export::GRAPH:
+            C->Menu_Option_Preferences_Inform(__T("Graph_Svg"));
+            file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
+            break;
         case Export::XML:
             C->Menu_View_XML();
             file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
@@ -1143,8 +1286,16 @@ void MainWindow::on_actionExport_triggered()
             C->Menu_View_NISO_Z39_87();
             file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
             break;
-        case Export::MPEG7:
-            C->Menu_View_MPEG7();
+        case Export::MPEG7_Strict:
+            C->Menu_View_MPEG7_Strict();
+            file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
+            break;
+        case Export::MPEG7_Relaxed:
+            C->Menu_View_MPEG7_Relaxed();
+            file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
+            break;
+        case Export::MPEG7_Extended:
+            C->Menu_View_MPEG7_Extended();
             file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
             break;
         default:
@@ -1162,6 +1313,18 @@ void MainWindow::on_actionAdvanced_Mode_toggled(bool checked)
     refreshDisplay();
 }
 
+void MainWindow::on_actionFull_Parse_toggled(bool checked)
+{
+    C->MI->Option_Static(__T("ParseSpeed"), checked?__T("1"):__T("0.5"));
+    refreshDisplay();
+}
+
+void MainWindow::on_actionTrace_toggled(bool checked)
+{
+    C->MI->Option_Static(__T("Trace_Level"), checked?__T("1"):__T("0"));
+    ui->menuView->actions().at(VIEW_TEXT)->trigger();
+}
+
 void MainWindow::on_actionClose_All_triggered()
 {
     C->Menu_File_Open_Files_Begin(true);
@@ -1183,3 +1346,12 @@ void MainWindow::buttonViewClicked()
     menuView->exec(buttonView->mapToGlobal(QPoint(0, 0)));
 #endif
 }
+
+void MainWindow::footerButtonClicked()
+{
+    const Ztring Inform_Save = C->Menu_Option_Preferences_Option(__T("Inform_Get"), __T(""));
+    C->Menu_Option_Preferences_Inform(__T("Conformance_JSON"));
+    const QString URL = wstring2QString(C->Inform_Get());
+    C->Menu_Option_Preferences_Inform(Inform_Save);
+    QDesktopServices::openUrl(QUrl(URL));
+}
